PyXMake Developer Guide: PyXMake.Tools.ErrorHandling.Error Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | List of all members
PyXMake.Tools.ErrorHandling.Error Class Reference

Parent class inherited from built-in exception. More...

Inheritance diagram for PyXMake.Tools.ErrorHandling.Error:

## Public Member Functions
def | __getstate__ (self)
def | __setstate__ (self, _dict)

## Detailed Description

Parent class inherited from built-in exception.

    Base class for all exceptions in this module.

Definition at line 39 of file ErrorHandling.py.

## Member Function Documentation

## ◆ __getstate__()

def PyXMake.Tools.ErrorHandling.Error.__getstate__ | ( |  | self | ) |

    Prepare the object for pickling (2to3 compatible)

Definition at line 43 of file ErrorHandling.py.

## ◆ __setstate__()

def PyXMake.Tools.ErrorHandling.Error.__setstate__ | ( |  | self,
|  |  | _dict
| ) |  |

    Recover a dictionary from pickling (2to3 compatible)

Definition at line 49 of file ErrorHandling.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/Tools/ErrorHandling.py